/**
 * Copyright 2007 Steven Van Impe, Department Of Applied Mathematics And Computer Science, Ghent University
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package gausselim.pivoting;

import java.util.Locale;
import java.util.ResourceBundle;

/**
 * Manager for available PivotingMethods.
 * 
 * @author Steven Van Impe (steven.vanimpe@ugent.be)
 */
public class PivotManager {

	private ResourceBundle bundle = ResourceBundle.getBundle("properties/gausselim", Locale.getDefault());
	
	/**
	 * @return descriptions for all available PivotingMethods
	 */
	public String[] getDescriptions() {
		return new String[] {bundle.getString("descriptionNoPivoting"), bundle.getString("descriptionRowPivoting"), bundle.getString("descriptionScaledRowPivoting")};
	}
	
	/**
	 * @return a description for the specified PivotingMethod
	 */
	public String getDescription(PivotingMethod pm) {
		if (pm instanceof RowPivoting)
			return getDescriptions()[1];
		else if (pm instanceof ScaledRowPivoting)
			return getDescriptions()[2];
		else
			// Default to NoPivoting
			return getDescriptions()[0];
	}
	
	/**
	 * @return a PivotingMethod for the specified description
	 */
	public PivotingMethod getPivotingMethod(String description) {
		if (description.equals(getDescriptions()[1]))
			return new RowPivoting();
		else if (description.equals(getDescriptions()[2]))
			return new ScaledRowPivoting();
		else
			// Default to NoPivoting
			return new NoPivoting();
	}
}
