/**
 * Copyright 2007 Steven Van Impe, Department Of Applied Mathematics And Computer Science, Ghent University
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package gausselim.systems;

import java.util.Locale;
import java.util.ResourceBundle;

/**
 * Manager for available ExampleSystems.
 * 
 * @author Steven Van Impe (steven.vanimpe@ugent.be)
 */
public class ExampleManager {

	private ResourceBundle bundle = ResourceBundle.getBundle("properties/gausselim", Locale.getDefault());
	
	/**
	 * @return descriptions for all available ExampleSystems
	 */
	public String[] getDescriptions() {
		return new String[] {bundle.getString("descriptionEmptySystem"), bundle.getString("descriptionHilbertSystem")};
	}
	
	/**
	 * @return a description for the specified ExampleSystem
	 */
	public String getDescription(ExampleSystem es) {
		if (es instanceof HilbertSystem)
			return getDescriptions()[1];
		else
			// Default to ZeroSystem
			return getDescriptions()[0];
	}
	
	/**
	 * @return an ExampleSystem for the specified description
	 */
	public ExampleSystem getExampleSystem(String description) {
		if (description.equals(getDescriptions()[1]))
			return new HilbertSystem();
		else
			// Default to ZeroSystem
			return new ZeroSystem();
	}
}
