/**
 * Copyright 2007 Steven Van Impe, Department Of Applied Mathematics And Computer Science, Ghent University
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package gausselim.systems;

import java.math.BigDecimal;
import java.math.MathContext;

/**
 * Hilbert system where A is a Hilbert matrix and b is a vector containing the row sums of A.
 * 
 * @author Steven Van Impe (steven.vanimpe@ugent.be)
 */
public class HilbertSystem implements ExampleSystem {

	/**
	 * Fill A with a Hilbert matrix and b with the row sums of A.
	 */
	public void fill(BigDecimal[][] a, BigDecimal[] b, MathContext mc) {
		
		for (int i = 0; i < a.length; i++) {
			BigDecimal sum = new BigDecimal("0.0", mc);
			for (int j = 0; j < a.length; j++) {
				// A(i,j) =  1/(i + j - 1)
				a[i][j] = new BigDecimal("1.0", mc).divide(new BigDecimal("" + (i + j + 1), mc), mc);
				sum = sum.add(a[i][j], mc);
			}
			// b(i) = sum(A(i,j), j=1..order)
			b[i] = sum;
		}
	}
}
